@@ -50,7 +50,7 @@ class TestAdjustments(unittest.TestCase):
             connection_limit='1000', cleanup_interval='1100',
             channel_timeout='1200', log_socket_errors='true',
             max_request_header_size='1300', max_request_body_size='1400',
-            expose_tracebacks='true', ident='abc')
+            expose_tracebacks='true', ident='abc', asyncore_loop_timeout='5')
         self.assertEqual(inst.host, 'host')
         self.assertEqual(inst.port, 8080)
         self.assertEqual(inst.threads, 5)
@@ -67,6 +67,7 @@ class TestAdjustments(unittest.TestCase):
         self.assertEqual(inst.max_request_header_size, 1300)
         self.assertEqual(inst.max_request_body_size, 1400)
         self.assertEqual(inst.expose_tracebacks, True)
+        self.assertEqual(inst.asyncore_loop_timeout, 5)
         self.assertEqual(inst.ident, 'abc')
 
     def test_badvar(self):
