@@ -25,7 +25,7 @@ class TestThreadedTaskDispatcher(unittest.TestCase):
         inst.handler_thread(0)
         self.assertEqual(inst.stop_count, -1)
         self.assertEqual(inst.threads, {})
-        self.assertTrue(len(inst.logger.logged), 1)
+        self.assertEqual(len(inst.logger.logged), 1)
 
     def test_set_thread_count_increase(self):
         inst = self._makeOne()
@@ -444,7 +444,7 @@ class TestWSGITask(unittest.TestCase):
         inst.logger = DummyLogger()
         inst.execute()
         self.assertEqual(inst.close_on_finish, True)
-        self.assertTrue(len(inst.logger.logged), 1)
+        self.assertEqual(len(inst.logger.logged), 1)
 
     def test_execute_app_returns_too_few_bytes(self):
         def app(environ, start_response):
@@ -455,7 +455,19 @@ class TestWSGITask(unittest.TestCase):
         inst.logger = DummyLogger()
         inst.execute()
         self.assertEqual(inst.close_on_finish, True)
-        self.assertTrue(len(inst.logger.logged), 1)
+        self.assertEqual(len(inst.logger.logged), 1)
+
+    def test_execute_app_do_not_warn_on_head(self):
+        def app(environ, start_response):
+            start_response('200 OK', [('Content-Length', '3')])
+            return [b'']
+        inst = self._makeOne()
+        inst.request.command = 'HEAD'
+        inst.channel.server.application = app
+        inst.logger = DummyLogger()
+        inst.execute()
+        self.assertEqual(inst.close_on_finish, True)
+        self.assertEqual(len(inst.logger.logged), 0)
 
     def test_execute_app_returns_closeable(self):
         class closeable(list):
